#' BootStrappedAA
#' Performs a bootstrapped accuracy assessment
#' @param df = data frame
#' @param k = iterations
#' @param frm = formula for glm or nnet library
#'
#' @return = matrix of frequencies which can be used with getBootMeanCL to get mean and lower, and upper CL
bootStrappedAA <- function(df, k, frm) {
    #df = dfp
    #frm = fm1
    #alpha = 0.05
    #k = 1

    rvar = all.vars(frm)[1]
    unqClss = unique(df[rvar][[1]])
    clCnt = length(unqClss)
    porMat = matrix(ncol = clCnt ^ 2, nrow = k)
    n = nrow(df)
    nv = 1:n
    for (i in 1:k) {
        dfb = df[sample(nv, n, replace = TRUE),]
        if (clCnt > 2) {
            tlm1 = multinom(frm, data = dfb, trace=F)
            dfb$pred = predict(tlm1,newdata=dfb,type="class")
        }
        if (clCnt == 2) {
            tlm1 = glm(frm, family = binomial(), data = dfb)
            dfb$pred = predict(tlm1,type="response")>0.5
        }
        rvect = vector(mode = "numeric", length = clCnt ^ 2)
        cCnt = 1
        for (l in levels(unqClss)) {
            for (l2 in levels(unqClss)) {
                rvect[cCnt] = sum(as.character(dfb[rvar][[1]]) == l & as.character(dfb$pred) == l2)
                cCnt = cCnt + 1
            }
        }
        porMat[i,]<-rvect
    }
    return(porMat)
}

#' getBootMeanCL
#' gets the mean and upper and lower CL from a vector of values
#' @param x = vector of values
#' @param alpha = confidence level
#'
#' @return = c(mean, lower and upper) values
getBootMeanCL <- function(x, alpha = 0.5) {
    k=length(x)
    vs = sort(x)
    a = alpha / 2
    ab = round(a * k)
    ae = round((1 - a) * k)
    return(c(mean(vs),vs[ab],vs[ae]))
}