Supplemental Material A: Iterative Variable Selection Routine
R function developed and used to iteratively select variables used in land cover and forest characteristics models.

library(mgcv)

#exhaustive search for significant variables
#indata=dataframe used to search variables
#resp=response variable name
#pred=list of predictive variabels
#alpha=level to include significant variabels
#improveby=the amount the model must improve % deviance explained to include a new    #variable
#returns a list of significant variables and best model 
getGamSigFldNames<-function(indata,resp,pred,alpha,fam=gaussian(),improveby=0)
{
  bModel<-NULL
  sigVar<-c()
  pdiv<-0
  pr2<-0
  for(i in seq(length(pred)))
  {
    vars<-c(sigVar,pred[i])
    fm<-as.formula(paste(resp," ~ ",paste("s(",vars,")",collapse=" + ")))
    md <- gam(fm,data=indata,family=fam)
    smry<-summary(md)
    div<-smry$dev.expl
    if(div>(pdiv+improveby))
    {
      print(paste("Adding variable", pred[i],collapse = " "))
      pvalues<-c(smry$s.pv)
      sigVar<-c()
      nonSigVar<-c()
      for (j in seq(length(vars))) 
      {
        pv<-pvalues[j]
        if(pv<=alpha)
        {
          sigVar<-c(sigVar,vars[j])
        }
        else
        {
          nonSigVar<-c(nonSigVar,vars[j])
          
        }
      }
      if(length(nonSigVar)>0)
      {
        for (k in nonSigVar) 
        {
          print(paste(cat("\t"),"Rechecking non significant variables",k,collapse=" "))
          vars2<-c(sigVar,k)
          cfm<-as.formula(paste(resp," ~ ",paste("s(",vars2,")",collapse=" + ")))
          nmd <- gam(cfm,data=indata,family=fam)
          nsmry<-summary(nmd)
          ndiv<-nsmry$dev.expl
          pvalues<-c(nsmry$s.pv)
          if(pvalues[length(vars2)]<=alpha)
          {
            #ndiv<-smry$dev.expl
            #pdiv<-smry$dev.expl
            sigVar<-c(sigVar,k)
            print(paste(cat("\t"),"adding",k,"back to the model",collapse=" "))
          }
        }
        ndiv<-pdiv
        if(length(sigVar)>0)
        {
          cfm<-as.formula(paste(resp," ~ ",paste("s(",sigVar,")",collapse=" + ")))
          nmd <- gam(cfm,data=indata,family=fam)
          nsmry<-summary(nmd)
          ndiv<-nsmry$dev.expl
        }
        if(ndiv < (pdiv + improveby))
        {
          print(paste(cat("\t"),"No improvement. Changing sig variables back"))
          sigVar<-vars[1:length(vars)-1]
        }
        else
        {
          pdiv<-ndiv
        }
        
      }
      else
      {
        pdiv<-div
      }
      print(paste(cat("\t"),"sig var for iter ",i,"(%Div = ",pdiv,"):",paste(sigVar,collapse=" ")))
    }
  }
  cfm<-as.formula(paste(resp," ~ ",paste("s(",sigVar,")",collapse=" + ")))
  nmd <- gam(cfm,data=indata,family=fam)
  return(list(sigVar,nmd))
}
