#' HurdleBootRmse
#' Performs boot strapping for a hurdle model
#' @param df = data frame
#' @param k = iterations
#' @param frm1 = logistic formula (glm)
#' @param frm2 = second formula (glm)
#' @param BAH = switch for square root (TRUE) or log (FALSE) transformtion
#' @param alpha = alpha confidence level (0.05 = 95% confidence)
hurdleBootRmse <- function(df, k, frm1, frm2, BAH = T, alpha = 0.05) {
    #frm1 = frm1
    #frm2 = frm3
    #BAH = F
    #k = 100
    #df = dfp
    #alpha = 0.05

    n = nrow(df)
    nv = 1:n
    rvar = all.vars(frm1)[1]
    svar = all.vars(frm2)[1]
    bg = 4
    if (BAH) bg = 5
    svar2 = substr(svar, bg, nchar(svar))
    rmseV = vector(mode = "numeric", k)
    porMat = matrix(ncol=4,nrow=k)
    for (i in 1:k) {
        dfb = df[sample(nv, n, replace = TRUE),]
        tlm1 = glm(frm1, family = binomial(), data = dfb)
        tlm2 = glm(frm2, data = dfb[dfb[svar2] > 0,])
        dfb$pred1 = predict(tlm1, type = "response") >= 0.5
        if (BAH) {
            #print("found bah")
             dfb$pred2 = (predict(tlm2, newdata = dfb) ^ 2) * dfb$pred1
        }
        if (!BAH) {
            #print("not bah")
            dfb$pred2 = exp(predict(tlm2, newdata = dfb)) * dfb$pred1
        }
        rmse = sqrt(mean((dfb[svar2][[1]] - dfb$pred2) ^ 2))
        rmseV[i] = rmse
        aa = sum(dfb[rvar][[1]] == T & dfb$pred1 == T) 
        ab = sum(dfb[rvar][[1]] == T & dfb$pred1 == F)
        bb = sum(dfb[rvar][[1]] == F & dfb$pred1 == F) 
        ba = sum(dfb[rvar][[1]] == F & dfb$pred1 == T) 
        porMat[i,]<-c(aa,ab,bb,ba)
    }
    rmseCL= getBootMeanCL(rmseV)
    return(list(rmseCL,porMat))
}
#' getBootMeanCL
#' gets the mean and upper and lower CL from a vector of values
#' @param x = vector of values
#' @param alpha = confidence level
#'
#' @return = c(mean, lower and upper) values
getBootMeanCL <- function(x, alpha = 0.5) {
    k=length(x)
    vs = sort(x)
    a = alpha / 2
    ab = round(a * k)
    ae = round((1 - a) * k)
    return(c(mean(vs),vs[ab],vs[ae]))
}